@@ -2,5 +2,7 @@ from .. import Provider as BankProvider
 
 
 class Provider(BankProvider):
-    bban_format = '????#############'
+    """Implement bank provider for ``en_GB`` locale."""
+
+    bban_format = '????##############'
     country_code = 'GB'
