@@ -1,5 +1,3 @@
-# coding=utf-8
-from __future__ import unicode_literals
 from .. import Provider as InternetProvider
 
 
@@ -32,4 +30,4 @@ class Provider(InternetProvider):
         'inmail.sk',
     )
 
-    tlds = ('sk', 'com',)
+    tlds = ('sk', 'com')
