@@ -23,6 +23,6 @@ class Provider(BaseProvider):
         aadhaar_digits = self.numerify(self.random_element(self.aadhaar_id_formats))
         checksum = checksums.calculate_luhn(aadhaar_digits)
 
-        aadhaar_number = '{}{}'.format(aadhaar_digits, checksum)
+        aadhaar_number = f'{aadhaar_digits}{checksum}'
 
         return aadhaar_number
