@@ -1,8 +1,4 @@
-# coding=utf-8
-
-from __future__ import unicode_literals
 from .. import Provider as SsnProvider
-from math import ceil
 
 
 class Provider(SsnProvider):
