@@ -77,5 +77,5 @@ class Provider(SsnProvider):
             # https://no.wikipedia.org/wiki/F%C3%B8dselsnummer
             if k1 == 10 or k2 == 10:
                 continue
-            pnr += '{}{}'.format(k1, k2)
+            pnr += f'{k1}{k2}'
             return pnr
